@@ -5,13 +5,9 @@ from typing import Any, Optional
 
 from aiohttp import web
 from aiohttp.test_utils import TestClient
+from aiohttp.typedefs import Handler
 
-from aiohttp_session import (
-    Handler,
-    SimpleCookieStorage,
-    get_session,
-    session_middleware,
-)
+from aiohttp_session import SimpleCookieStorage, get_session, session_middleware
 
 from .typedefs import AiohttpClient
 
@@ -23,7 +19,7 @@ def make_cookie(
     domain: Optional[str] = None,
 ) -> None:
     session_data = {"session": data, "created": int(time.time())}
-    C: cookies.SimpleCookie[str] = cookies.SimpleCookie()
+    C = cookies.SimpleCookie()
     value = json.dumps(session_data)
     C["AIOHTTP_SESSION"] = value
     C["AIOHTTP_SESSION"]["path"] = path
